package com.jeeplus.test.wdt.disposeRubbish.controller;

import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jeeplus.aop.logging.annotation.ApiLog;
import com.jeeplus.common.utils.ResponseUtil;
import com.jeeplus.notify.service.NotifyService;
import com.jeeplus.notify.service.dto.NotifyDTO;
import com.jeeplus.sys.service.OfficeService;
import com.jeeplus.sys.service.dto.OfficeDTO;
import com.jeeplus.sys.service.dto.UserDTO;
import com.jeeplus.sys.utils.StringUtils;
import com.jeeplus.sys.utils.UserUtils;
import com.jeeplus.test.garbageClearance.domain.LookOver;
import com.jeeplus.test.garbageClearance.service.DTO.LookOverDTO;
import com.jeeplus.test.garbageClearance.service.LookOverService;
import com.jeeplus.test.garbageClearance.utils.SnowFlake;
import com.jeeplus.test.oss.domain.WorkAttachment;
import com.jeeplus.test.oss.domain.WorkAttachmentInfo;
import com.jeeplus.test.oss.service.OssService;
import com.jeeplus.test.wdt.disposeRubbish.domain.DisposeRubbish;
import com.jeeplus.test.wdt.disposeRubbish.service.DisposeRubbishService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.validation.Valid;
import java.util.Date;
import java.util.Iterator;
import java.util.List;

/**
 * 清运处理
 * @author: 徐滕
 * @version: 2024-09-02 09:50
 */
@Api(tags ="清运处理")
@RestController
@RequestMapping(value = "/app/dispose/rubbish")
public class DisposeRubbishController {
    @Autowired
    private DisposeRubbishService disposeRubbishService;
    @Autowired
    private LookOverService overService;

    @Autowired
    private OfficeService officeService;

    @Autowired
    private OssService ossService;

    @Autowired
    private NotifyService notifyService;

    /**
     * 查询巡视工单
     *
     * @param id
     * @return
     */
    @GetMapping("queryById")
    public ResponseEntity queryById(String id) {
        // 还需要处理单位  清运专员  联系方式  及  附件信息
        DisposeRubbish post = disposeRubbishService.selectById ( id );

        return ResponseEntity.ok ( post );
    }

    /**
     * 查询巡视工单
     *
     * @param id
     * @return
     */
    @GetMapping("getByProcInsId")
    public ResponseEntity getByProcInsId(String procInsId) {
        // 还需要处理单位  清运专员  联系方式  及  附件信息
        DisposeRubbish post = disposeRubbishService.getByProcInsId ( procInsId );

        return ResponseEntity.ok ( post );
    }

    /**
     * 保存巡视信息
     */
    @ApiLog("保存巡视信息")
    @ApiOperation(value = "保存巡视信息")
    @PostMapping("save")
    public  ResponseEntity <String> save(@Valid @RequestBody DisposeRubbish disposeRubbish) {
        //新增或编辑表单保存
        if (StringUtils.isNotBlank(disposeRubbish.getNo())) {
            // 剔除掉XJ-J 只保留纯数字
            // 使用正则表达式替换掉所有非数字字符
            String pureNumber = disposeRubbish.getNo().replaceAll("\\D+", "");
            disposeRubbish.setNo(pureNumber);
        }
        if(disposeRubbish.getProgramIds().size()>0){
            String programIds = String.join(",", disposeRubbish.getProgramId());
            disposeRubbish.setProgramId(programIds);
        }


        disposeRubbishService.saveOrUpdate (disposeRubbish);


        //对过磅数据进行处理
        if (null != disposeRubbish.getFileList4() && disposeRubbish.getFileList4().size() > 0 ) {
            UserDTO userDTO = UserUtils.getCurrentUserDTO();
            // 进行附件保存操作，保存到work_attachment 表中
            for (WorkAttachment attachment : disposeRubbish.getFileList4()) {
                // 生成id
                String detailId = SnowFlake.getId();
                attachment.setId(detailId);
                attachment.setAttachmentId(disposeRubbish.getId());
                attachment.setCreateTime(new Date());
                attachment.setUpdateTime(new Date());
                attachment.setDelFlag(0);
                attachment.setAttachmentFlag("weigh");
                ossService.insertWorkAttachment(attachment,userDTO);
            }
        }

        for (String workOverId : disposeRubbish.getProgramIds()) {
            LookOver lookOver = overService.getById(workOverId);
            //处理巡查单的状态信息，将巡查单的status调整为处理中
            if("2".equals(disposeRubbish.getStatus()) || "5".equals(disposeRubbish.getStatus())){
                lookOver.setStatus(disposeRubbish.getStatus());
            }else{
                lookOver.setStatus("1");
            }
            overService.updateStatus(lookOver);
        }
        return ResponseUtil.newInstance ( ).add("businessTable", "dispose_rubbish").add("businessId", disposeRubbish.getId()).ok ("保存成功");
    }

    /**
     * 查询最大的巡视工单
     */
    @ApiLog("查询最大的巡视工单")
    @ApiOperation(value = "查询最大的巡视工单")
    @GetMapping("getMaxNo")
    public ResponseEntity<String> getMaxNo() {
        String maxNo = disposeRubbishService.getMaxNo();
        return ResponseEntity.ok( maxNo );
    }

    /**
     * 查询最大的巡视工单
     */
    @ApiLog("查询垃圾站点")
    @ApiOperation(value = "查询垃圾站点")
    @GetMapping("getRubbishStation")
    public ResponseEntity<String> getRubbishStation() {
        //String maxNo = disposeRubbishService.getMaxNo();
        String rubbishStation = "头灶镇垃圾处理点";
        return ResponseEntity.ok( rubbishStation );
    }

    /**
     * 查询处理单位
     */
    @ApiLog("查询处理单位")
    @ApiOperation(value = "查询处理单位")
    @GetMapping("getProcessingUnit")
    public ResponseEntity<List<OfficeDTO>> getProcessingUnit() {
        List <OfficeDTO> list = officeService.findList ( "" );
        List <OfficeDTO> rootTree = officeService.getRootTree ( "", list, "", "", "1" );

        rootTree.forEach(ro -> {
            Iterator<OfficeDTO> iterator = ro.getChildren().iterator();
            while (iterator.hasNext()) {
                OfficeDTO ch = iterator.next();
                if (!ch.getName().contains("村")) {
                    iterator.remove();  // 使用迭代器删除子节点
                }
            }
        });

        return ResponseEntity.ok ( rootTree );
    }

    /**
     * 根据组织ID获取角色为村负责人的用户信息
     */
    @ApiLog("根据组织ID获取角色为村负责人的用户信息")
    @ApiOperation(value = "根据组织ID获取角色为村负责人的用户信息")
    @GetMapping("getUserInfoByOffId")
    public ResponseEntity<UserDTO> getUserInfo(String officeId ) {
        UserDTO userDTO = disposeRubbishService.getUserInfoByOffId(officeId);
        return ResponseEntity.ok( userDTO );
    }
}
